@@ -1,10 +1,12 @@
-__version__ = "0.1.2"
+__version__ = "0.2.0"
 __author__ = "SkyLothar"
 __email__ = "allothar@gmail.com"
 __url__ = "http://github.com/skylothar/requests-aliyun"
 
-from .oss import OssAuth
 from .ecs import EcsAuth
+from .oss import OssAuth
+from .rds import RdsAuth
+from .slb import SlbAuth
 
 
-__all__ = ["EcsAuth", "OssAuth"]
+__all__ = ["EcsAuth", "OssAuth", "RdsAuth", "SlbAuth"]
